# Copyright 2013-2019 Ben Lambert

# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at

#     http://www.apache.org/licenses/LICENSE-2.0

# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
Unit tests for edit_distance.
"""
from __future__ import division

import unittest
import random
import string

from edit_distance import edit_distance_backpointer
from edit_distance import edit_distance

class TestLongSequences(unittest.TestCase):

    def test_long_seq(self):

        self.assertEqual((893, 159), edit_distance(TestLongSequences.a, TestLongSequences.b))
        self.assertEqual(TestLongSequences.bp_expected_result, edit_distance_backpointer(TestLongSequences.a, TestLongSequences.b))


    # these were generated with:
    # [random.choice(string.ascii_lowercase) for i in range(1000)]

    a = ['d', 'v', 'v', 'w', 'x', 'j', 'o', 'o', 'd', 'z', 'f', 'm', 'd', 't', 'm', 's', 'u', 'b', 'z', 'b', 'b', 'l', 'j', 'i', 'p', 'q', 'o', 'o', 'v', 'o', 'z', 'h', 'p', 'd', 'e', 'u', 'i', 'k', 'w', 'r', 'h', 'o', 'j', 'i', 'e', 'n', 'q', 'v', 'v', 'j', 'v', 's', 'k', 'p', 'u', 'i', 'e', 'b', 'w', 'e', 'w', 'w', 'h', 'l', 'u', 'u', 'v', 't', 'r', 'k', 'k', 's', 'j', 'r', 'a', 'z', 'k', 'u', 'i', 'j', 'j', 'h', 'b', 'l', 'b', 'm', 'e', 'x', 'm', 'p', 'a', 'm', 'x', 'i', 'u', 't', 'd', 'w', 'w', 'u', 's', 'h', 's', 'x', 'c', 'g', 'h', 'c', 'd', 'p', 'p', 'p', 's', 'b', 'k', 'p', 'k', 'a', 't', 'x', 's', 'n', 'r', 'j', 'l', 'e', 'b', 'b', 'a', 'e', 'r', 'p', 'z', 'n', 'w', 'z', 'h', 'k', 'd', 'h', 'z', 'j', 'k', 'w', 'i', 'b', 'g', 't', 'y', 'v', 'p', 'j', 'a', 'f', 'l', 'g', 'v', 'm', 'y', 'z', 'm', 'e', 'h', 'o', 'z', 'c', 'b', 'c', 'c', 'm', 'v', 'v', 'q', 'e', 'l', 't', 'z', 'a', 'e', 'w', 's', 's', 'q', 'd', 's', 's', 'v', 'y', 'h', 'p', 'e', 'q', 'v', 'p', 'b', 'f', 'h', 'm', 'p', 's', 'k', 'b', 'x', 'd', 'u', 'k', 'a', 'b', 't', 'v', 'b', 'd', 'c', 'm', 'g', 'h', 'v', 'q', 'r', 'g', 'n', 'i', 'v', 'c', 'b', 'f', 'f', 's', 'p', 'i', 's', 'g', 'c', 'm', 'm', 'n', 'c', 'l', 'y', 'a', 'q', 'a', 'i', 'w', 'l', 'x', 'p', 'x', 'h', 't', 'g', 'x', 'd', 'j', 'h', 'u', 'j', 'i', 'n', 'q', 'l', 'y', 'k', 'g', 'c', 'y', 'h', 'x', 'z', 's', 'o', 'o', 'g', 'h', 'a', 'z', 'm', 'v', 'd', 'r', 'j', 'm', 'j', 'w', 'd', 'l', 'v', 'w', 'a', 'p', 'i', 'b', 'z', 'a', 'p', 'g', 's', 'm', 'x', 'm', 'f', 'x', 'c', 'v', 'z', 'z', 'v', 'r', 'p', 's', 'w', 't', 's', 'm', 'x', 'v', 'i', 'n', 'x', 'd', 'u', 'a', 'n', 'y', 'd', 'v', 'x', 'l', 'o', 'r', 'b', 'k', 's', 'o', 'w', 'o', 'n', 'o', 'd', 'e', 'm', 'm', 'v', 'c', 'x', 'e', 'l', 'g', 'c', 'y', 'd', 'e', 'e', 'l', 'o', 'z', 'o', 'p', 't', 'z', 'w', 't', 'o', 'a', 'a', 'y', 't', 'q', 'w', 'm', 'i', 'd', 'd', 'f', 'c', 'j', 'f', 'e', 'g', 'i', 'a', 's', 'p', 'f', 'r', 'g', 'u', 'p', 'b', 'c', 'z', 'r', 'a', 'k', 'h', 'm', 'x', 'h', 'y', 'q', 'n', 't', 'd', 'l', 'g', 'o', 'g', 'h', 'c', 'p', 'c', 'x', 'w', 'c', 'w', 'j', 'q', 'j', 't', 'c', 'w', 'h', 'x', 'j', 'l', 'g', 'y', 'v', 't', 'z', 'w', 'b', 'd', 'g', 'v', 'v', 'a', 'r', 'q', 'm', 'i', 'b', 'g', 'e', 'j', 'a', 'a', 'x', 'v', 'k', 'l', 't', 'c', 'c', 'f', 'm', 'v', 'i', 'n', 'q', 'l', 'x', 'p', 'z', 'v', 'z', 'j', 'l', 't', 'x', 'v', 'u', 'h', 'i', 'i', 'd', 'x', 'q', 'k', 's', 'k', 's', 'k', 'y', 'd', 'l', 'v', 'z', 'h', 'x', 'b', 'i', 'c', 'u', 'h', 'i', 'm', 'l', 'm', 'o', 'a', 't', 's', 'c', 'i', 'y', 'o', 'x', 'o', 'r', 'f', 'm', 'c', 'g', 'g', 'j', 'x', 'f', 'a', 'j', 'b', 'z', 'h', 'n', 'p', 'n', 'a', 'j', 'n', 'q', 'u', 'd', 'w', 'h', 'l', 'u', 'a', 'a', 'p', 'n', 'l', 'r', 'p', 'l', 'u', 'f', 'f', 'b', 'h', 'z', 'i', 'i', 'm', 'b', 'h', 'm', 'q', 'b', 'z', 's', 'n', 's', 'h', 't', 'i', 'v', 'e', 'l', 'i', 'f', 'd', 'b', 'f', 'z', 'm', 'f', 'f', 'j', 'p', 'z', 'u', 'k', 'g', 'y', 'l', 's', 'm', 'l', 'a', 'c', 'w', 'x', 'z', 'a', 'n', 'v', 's', 'i', 'p', 'u', 'f', 'o', 'k', 'n', 's', 'u', 'h', 's', 'r', 'm', 'k', 'm', 's', 'e', 'b', 'a', 'd', 's', 'o', 'b', 'b', 'l', 'a', 'w', 'j', 'b', 'o', 'g', 'm', 'r', 'b', 'g', 'o', 'l', 'g', 't', 'g', 'i', 'a', 'q', 'i', 'r', 'w', 'e', 'o', 'q', 'i', 'o', 'm', 'e', 'x', 'm', 'u', 'l', 'x', 'x', 't', 'x', 'c', 'b', 'p', 'g', 'm', 'g', 's', 'v', 'q', 'p', 'j', 't', 's', 'd', 'x', 'u', 'g', 'x', 'w', 'r', 'a', 'm', 'x', 'q', 'e', 'c', 'g', 'd', 's', 'q', 'i', 'm', 'q', 'b', 'l', 'z', 'u', 'l', 'u', 'x', 'c', 'i', 'k', 'h', 'l', 'y', 'n', 'n', 'r', 'u', 'b', 'p', 'i', 'p', 'r', 'w', 'a', 'e', 'l', 'g', 'b', 'c', 'o', 'x', 'o', 'h', 'b', 'j', 'a', 'n', 'g', 'c', 'o', 'c', 'z', 't', 'j', 'b', 't', 'm', 'c', 'e', 's', 'u', 't', 'e', 'z', 'g', 'd', 'f', 'n', 'n', 'd', 'n', 'y', 'c', 'a', 'p', 'b', 'b', 'y', 'u', 'w', 'w', 'u', 'w', 'b', 'a', 'a', 'y', 'm', 'p', 'a', 's', 'i', 'o', 'c', 'u', 'y', 'm', 'u', 'n', 'w', 'y', 'v', 'p', 'u', 's', 'f', 'x', 'x', 'z', 'h', 'j', 't', 'e', 'k', 'b', 'x', 'g', 'v', 'i', 's', 'd', 'i', 'g', 's', 'm', 't', 'z', 'u', 'c', 'u', 'z', 'i', 'f', 'j', 'n', 's', 'e', 'f', 'g', 'n', 'h', 'g', 'h', 's', 'p', 'x', 's', 'r', 'c', 's', 'g', 'i', 'w', 'n', 'w', 'w', 'u', 't', 'h', 'u', 'e', 'i', 's', 'r', 'e', 'u', 'g', 'f', 'e', 's', 't', 'i', 'v', 'i', 'r', 'h', 'h', 'n', 'h', 'i', 'z', 'z', 'v', 't', 'z', 'w', 'p', 'z', 'l', 'g', 'z', 'y', 'e', 'm', 'f', 't', 'f', 'e', 'f', 'y', 'd', 'b', 'x', 's', 'h', 'g', 'r', 'o', 'h', 'q', 'p', 'u', 'g', 'd', 'u', 'a', 'k', 'p', 'e', 'f', 'n', 't', 'd', 'e', 's', 'l', 'l', 'b', 'u', 'h', 'y', 'j', 'f', 'e', 'j', 'o', 'k', 'u', 'q', 'k', 'h', 'u', 'k', 'x', 'y', 'i', 't', 'o', 'v', 'f', 'w', 'm', 'w', 'j', 'g', 'k', 'o', 'e', 'k', 'n', 'l', 's', 'p', 'r', 'n', 'q', 'u', 'q', 'r', 'q', 't', 'g', 'd', 'o', 'y', 'm', 'v', 'g', 'u', 'm', 'u', 's', 'h', 'e', 'w', 'x', 'h', 'm', 'a', 'q', 'n', 'v', 'z', 'd', 's', 'd', 'j', 'k', 'k', 'u', 'k', 'g', 'g', 'e', 'c', 'w', 'x', 's', 't', 't', 't', 'k', 's', 'm', 'p', 'h', 't', 'n', 'j']

    b = ['j', 's', 'g', 'o', 'a', 'x', 'a', 'w', 'z', 'c', 'e', 'e', 'y', 'q', 'x', 'w', 'b', 'l', 'h', 'g', 'c', 'r', 'k', 'k', 'h', 'j', 'o', 's', 'j', 'm', 'c', 'j', 'b', 'n', 'e', 'e', 'a', 'c', 'p', 'j', 'n', 'v', 'u', 'a', 'g', 'h', 'b', 'l', 'k', 'h', 'q', 'a', 'w', 'y', 'q', 'z', 'r', 's', 'x', 'o', 'l', 'x', 'c', 'h', 'm', 't', 'o', 'l', 'h', 'e', 't', 'y', 'c', 'a', 'h', 'z', 'p', 'k', 'f', 'r', 'c', 'u', 'y', 'j', 'l', 'p', 'j', 'u', 'b', 'i', 'u', 'c', 'f', 'u', 'n', 'o', 'n', 'h', 'n', 't', 'h', 's', 'b', 'p', 'v', 'b', 'w', 'w', 'b', 'x', 'j', 'j', 'k', 't', 'd', 'y', 'x', 'z', 'h', 't', 'c', 'c', 'r', 's', 'e', 'u', 'h', 'f', 'y', 'w', 'w', 'x', 'g', 'n', 'o', 'n', 'u', 'h', 'o', 'i', 'j', 'g', 'm', 'm', 'r', 'a', 'b', 'r', 'i', 'q', 'i', 'c', 'h', 'e', 'u', 'x', 'r', 'm', 'i', 'y', 'j', 't', 'i', 'k', 'l', 'f', 'z', 'o', 'p', 's', 'r', 'l', 'q', 'x', 'w', 'b', 'm', 's', 'q', 'f', 'f', 'm', 'y', 'o', 'f', 'g', 't', 'x', 'd', 'z', 'o', 'g', 'i', 'b', 'r', 'z', 't', 'o', 'i', 't', 'g', 'j', 'h', 'j', 't', 'x', 'r', 'd', 'p', 'g', 'h', 'u', 'w', 't', 'j', 'y', 'a', 'q', 'w', 'p', 'v', 'h', 'v', 'v', 'd', 'f', 'e', 'o', 't', 'u', 'e', 'e', 'c', 'g', 's', 'f', 'u', 'l', 'u', 'f', 't', 'm', 'o', 'r', 'e', 'b', 'u', 'u', 'h', 'l', 'k', 'w', 'y', 'i', 'h', 'j', 'f', 'b', 'r', 'o', 'v', 'n', 'h', 'e', 'i', 'l', 'm', 'b', 'l', 'x', 'h', 'c', 'm', 'n', 'r', 'd', 'z', 'n', 'p', 'z', 'm', 'i', 'g', 't', 'u', 'x', 's', 'd', 'm', 'd', 'k', 's', 'p', 'f', 'c', 'a', 't', 'h', 'q', 'v', 'i', 'v', 'r', 'n', 'e', 'd', 'z', 'd', 's', 'c', 't', 't', 'd', 'y', 'k', 'd', 'q', 'i', 'g', 'y', 't', 'k', 'm', 'n', 'e', 'u', 'x', 'x', 'k', 'g', 'd', 'v', 's', 'x', 'd', 't', 'w', 'x', 'o', 'b', 'g', 'w', 'k', 'k', 's', 's', 'n', 'z', 'l', 'u', 'y', 'l', 'e', 'm', 'h', 'i', 'p', 'e', 'r', 'm', 'u', 'i', 'w', 'm', 'w', 'e', 'w', 'i', 't', 'f', 'q', 'f', 'i', 'z', 'k', 'h', 'n', 'k', 'c', 'p', 'q', 's', 'o', 'f', 'd', 'l', 'p', 'h', 'a', 'u', 'd', 'a', 'h', 'a', 'w', 'i', 'o', 'v', 'f', 'b', 'h', 'n', 'n', 'c', 's', 'm', 'v', 'i', 'z', 'a', 'p', 'y', 'l', 'z', 'j', 'c', 'd', 'o', 'h', 'q', 'b', 'c', 'a', 's', 'h', 'w', 'o', 'b', 'u', 'i', 'z', 'p', 'g', 'w', 'x', 'l', 'u', 'p', 'r', 'd', 't', 'o', 'e', 'l', 's', 'h', 'd', 'i', 'l', 'h', 'v', 'f', 'b', 'a', 'b', 'g', 'l', 'q', 'k', 'm', 'n', 'a', 'e', 'n', 's', 'v', 'l', 'i', 's', 's', 'x', 'o', 'z', 'd', 'c', 'c', 'e', 'd', 'c', 'u', 'h', 'i', 't', 'x', 'y', 'q', 'y', 'g', 'h', 'y', 'h', 'h', 'f', 'b', 'a', 'i', 'e', 'v', 'j', 'r', 'w', 'v', 'u', 't', 'a', 'u', 'b', 'w', 'v', 'k', 'v', 'm', 'l', 't', 'p', 'e', 'v', 'd', 'e', 'm', 'p', 'o', 's', 'n', 'e', 'j', 't', 'x', 'o', 't', 'e', 'l', 'u', 'u', 'p', 'b', 'c', 'a', 'k', 'q', 'k', 'd', 'x', 'r', 'm', 't', 'a', 'r', 'r', 'x', 'o', 'x', 't', 'w', 'y', 't', 'e', 'n', 'x', 'a', 't', 'h', 'm', 'q', 'h', 'j', 'p', 'p', 'w', 'g', 'e', 'c', 'g', 't', 'a', 'm', 'x', 'm', 'g', 'k', 'f', 'k', 'a', 'n', 'o', 'v', 'k', 'x', 'p', 'e', 's', 'g', 'e', 'i', 'r', 'q', 'u', 'h', 'l', 'p', 'q', 'n', 'g', 't', 'p', 'h', 'k', 'y', 'p', 'p', 'e', 'h', 'm', 'r', 'p', 'd', 'y', 'd', 'e', 'o', 'g', 'e', 'y', 'f', 'i', 'r', 'r', 'c', 'x', 'w', 'k', 'n', 'd', 'n', 'r', 'g', 'k', 's', 'j', 'z', 'g', 'y', 'j', 't', 'f', 'm', 'i', 'g', 's', 'p', 'f', 'l', 'f', 'x', 'h', 'd', 'z', 'h', 'v', 't', 'e', 'w', 'f', 'n', 'a', 'o', 'd', 'n', 'p', 'u', 'e', 'r', 'f', 'k', 'z', 'w', 'q', 't', 'g', 'n', 'c', 'e', 'c', 'u', 'p', 't', 'r', 'y', 'n', 'k', 'o', 'q', 'p', 'h', 'c', 'c', 'c', 'h', 'p', 'h', 'n', 'o', 'o', 't', 'j', 'h', 'w', 'y', 'g', 'q', 'c', 'b', 'u', 'w', 'u', 'j', 'b', 'o', 'q', 'k', 'g', 'm', 'p', 's', 'i', 'h', 'o', 'w', 'x', 'u', 't', 'u', 'q', 'p', 'u', 'n', 'p', 'a', 'i', 'c', 'i', 'e', 'p', 'q', 'p', 'o', 's', 'c', 'c', 'w', 'c', 't', 'b', 'o', 'b', 'u', 'r', 'x', 'o', 'a', 'p', 'm', 'x', 'z', 'a', 'p', 'x', 'a', 'i', 'j', 'f', 't', 'u', 'v', 'h', 'z', 'g', 'a', 'o', 'w', 'k', 'u', 'n', 'l', 'a', 'v', 'y', 'n', 'q', 'f', 's', 'f', 'p', 'j', 'n', 'k', 'h', 'b', 'l', 'k', 'w', 'h', 'm', 't', 'z', 't', 'f', 'q', 'x', 'r', 't', 'a', 'w', 'd', 'q', 'f', 'i', 'g', 'd', 'n', 'l', 't', 'p', 's', 'x', 'm', 'o', 'i', 'x', 'g', 'z', 'j', 'u', 'q', 'j', 'h', 'p', 'z', 'n', 'p', 's', 'u', 'i', 'd', 'y', 'r', 'h', 'y', 'b', 'l', 'p', 'h', 'm', 's', 'y', 'l', 'h', 'y', 'w', 'j', 'b', 't', 'w', 'q', 'o', 'i', 's', 'y', 'v', 'l', 'h', 's', 'm', 'u', 'l', 'm', 'u', 'd', 'b', 'f', 'x', 'r', 'i', 's', 'e', 'e', 'z', 'j', 'q', 'l', 'y', 's', 'm', 'n', 'u', 'f', 'f', 'w', 's', 'o', 'y', 'u', 'l', 'b', 'g', 'e', 'a', 'o', 'x', 'd', 'd', 'z', 't', 'd', 't', 'j', 'q', 'b', 'w', 'j', 'z', 'l', 'a', 'y', 'e', 'j', 'q', 'g', 'o', 's', 'm', 'm', 'l', 'i', 'z', 'i', 'a', 'k', 'b', 'z', 'v', 'm', 'w', 'a', 'h', 'u', 's', 'n', 'd', 'k', 'o', 'f', 'h', 'j', 'l', 'h', 'c', 'y', 'f', 'b', 'g', 'm', 'j', 'q', 'y', 'q', 'v', 'w', 'x', 'i', 'o', 'n', 'd', 'x', 'p', 'e', 'y', 'b', 't', 'd', 'c', 'v', 'r', 'u', 'c', 'd', 'b', 'm', 'n', 'c', 'd', 'x', 'd', 'r', 'j', 'h', 'o', 'y', 'y', 's']

    bp_expected_result = (893, 159, [['delete', 0, 1, 0, 0], ['delete', 1, 2, 0, 0], ['delete', 2, 3, 0, 0], ['replace', 3, 4, 0, 1], ['replace', 4, 5, 1, 2], ['replace', 5, 6, 2, 3], ['equal', 6, 7, 3, 4], ['replace', 7, 8, 4, 5], ['replace', 8, 9, 5, 6], ['replace', 9, 10, 6, 7], ['replace', 10, 11, 7, 8], ['replace', 11, 12, 8, 9], ['replace', 12, 13, 9, 10], ['replace', 13, 14, 10, 11], ['replace', 14, 15, 11, 12], ['replace', 15, 16, 12, 13], ['replace', 16, 17, 13, 14], ['replace', 17, 18, 14, 15], ['replace', 18, 19, 15, 16], ['equal', 19, 20, 16, 17], ['replace', 20, 21, 17, 18], ['replace', 21, 22, 18, 19], ['replace', 22, 23, 19, 20], ['replace', 23, 24, 20, 21], ['replace', 24, 25, 21, 22], ['replace', 25, 26, 22, 23], ['replace', 26, 27, 23, 24], ['replace', 27, 28, 24, 25], ['replace', 28, 29, 25, 26], ['equal', 29, 30, 26, 27], ['replace', 30, 31, 27, 28], ['replace', 31, 32, 28, 29], ['replace', 32, 33, 29, 30], ['replace', 33, 34, 30, 31], ['replace', 34, 35, 31, 32], ['replace', 35, 36, 32, 33], ['replace', 36, 37, 33, 34], ['replace', 37, 38, 34, 35], ['replace', 38, 39, 35, 36], ['replace', 39, 40, 36, 37], ['replace', 40, 41, 37, 38], ['replace', 41, 42, 38, 39], ['equal', 42, 43, 39, 40], ['delete', 43, 44, 39, 39], ['delete', 44, 45, 39, 39], ['equal', 45, 46, 40, 41], ['delete', 46, 47, 40, 40], ['equal', 47, 48, 41, 42], ['replace', 48, 49, 42, 43], ['replace', 49, 50, 43, 44], ['replace', 50, 51, 44, 45], ['replace', 51, 52, 45, 46], ['replace', 52, 53, 46, 47], ['replace', 53, 54, 47, 48], ['replace', 54, 55, 48, 49], ['replace', 55, 56, 49, 50], ['replace', 56, 57, 50, 51], ['replace', 57, 58, 51, 52], ['equal', 58, 59, 52, 53], ['delete', 59, 60, 52, 52], ['replace', 60, 61, 53, 54], ['replace', 61, 62, 54, 55], ['replace', 62, 63, 55, 56], ['replace', 63, 64, 56, 57], ['replace', 64, 65, 57, 58], ['replace', 65, 66, 58, 59], ['replace', 66, 67, 59, 60], ['replace', 67, 68, 60, 61], ['replace', 68, 69, 61, 62], ['replace', 69, 70, 62, 63], ['replace', 70, 71, 63, 64], ['replace', 71, 72, 64, 65], ['replace', 72, 73, 65, 66], ['replace', 73, 74, 66, 67], ['replace', 74, 75, 67, 68], ['replace', 75, 76, 68, 69], ['replace', 76, 77, 69, 70], ['replace', 77, 78, 70, 71], ['replace', 78, 79, 71, 72], ['replace', 79, 80, 72, 73], ['replace', 80, 81, 73, 74], ['equal', 81, 82, 74, 75], ['replace', 82, 83, 75, 76], ['replace', 83, 84, 76, 77], ['replace', 84, 85, 77, 78], ['replace', 85, 86, 78, 79], ['replace', 86, 87, 79, 80], ['replace', 87, 88, 80, 81], ['replace', 88, 89, 81, 82], ['replace', 89, 90, 82, 83], ['replace', 90, 91, 83, 84], ['replace', 91, 92, 84, 85], ['replace', 92, 93, 85, 86], ['replace', 93, 94, 86, 87], ['equal', 94, 95, 87, 88], ['delete', 95, 96, 87, 87], ['delete', 96, 97, 87, 87], ['replace', 97, 98, 88, 89], ['replace', 98, 99, 89, 90], ['equal', 99, 100, 90, 91], ['replace', 100, 101, 91, 92], ['replace', 101, 102, 92, 93], ['replace', 102, 103, 93, 94], ['replace', 103, 104, 94, 95], ['replace', 104, 105, 95, 96], ['replace', 105, 106, 96, 97], ['equal', 106, 107, 97, 98], ['delete', 107, 108, 97, 97], ['delete', 108, 109, 97, 97], ['replace', 109, 110, 98, 99], ['replace', 110, 111, 99, 100], ['replace', 111, 112, 100, 101], ['equal', 112, 113, 101, 102], ['equal', 113, 114, 102, 103], ['delete', 114, 115, 102, 102], ['equal', 115, 116, 103, 104], ['delete', 116, 117, 103, 103], ['replace', 117, 118, 104, 105], ['replace', 118, 119, 105, 106], ['replace', 119, 120, 106, 107], ['replace', 120, 121, 107, 108], ['replace', 121, 122, 108, 109], ['replace', 122, 123, 109, 110], ['equal', 123, 124, 110, 111], ['replace', 124, 125, 111, 112], ['replace', 125, 126, 112, 113], ['replace', 126, 127, 113, 114], ['replace', 127, 128, 114, 115], ['replace', 128, 129, 115, 116], ['replace', 129, 130, 116, 117], ['replace', 130, 131, 117, 118], ['replace', 131, 132, 118, 119], ['replace', 132, 133, 119, 120], ['replace', 133, 134, 120, 121], ['replace', 134, 135, 121, 122], ['replace', 135, 136, 122, 123], ['replace', 136, 137, 123, 124], ['replace', 137, 138, 124, 125], ['replace', 138, 139, 125, 126], ['equal', 139, 140, 126, 127], ['delete', 140, 141, 126, 126], ['replace', 141, 142, 127, 128], ['replace', 142, 143, 128, 129], ['equal', 143, 144, 129, 130], ['replace', 144, 145, 130, 131], ['replace', 145, 146, 131, 132], ['equal', 146, 147, 132, 133], ['replace', 147, 148, 133, 134], ['replace', 148, 149, 134, 135], ['replace', 149, 150, 135, 136], ['replace', 150, 151, 136, 137], ['replace', 151, 152, 137, 138], ['replace', 152, 153, 138, 139], ['replace', 153, 154, 139, 140], ['replace', 154, 155, 140, 141], ['equal', 155, 156, 141, 142], ['replace', 156, 157, 142, 143], ['equal', 157, 158, 143, 144], ['replace', 158, 159, 144, 145], ['replace', 159, 160, 145, 146], ['replace', 160, 161, 146, 147], ['replace', 161, 162, 147, 148], ['replace', 162, 163, 148, 149], ['replace', 163, 164, 149, 150], ['replace', 164, 165, 150, 151], ['equal', 165, 166, 151, 152], ['replace', 166, 167, 152, 153], ['replace', 167, 168, 153, 154], ['replace', 168, 169, 154, 155], ['replace', 169, 170, 155, 156], ['replace', 170, 171, 156, 157], ['replace', 171, 172, 157, 158], ['replace', 172, 173, 158, 159], ['replace', 173, 174, 159, 160], ['replace', 174, 175, 160, 161], ['equal', 175, 176, 161, 162], ['delete', 176, 177, 161, 161], ['replace', 177, 178, 162, 163], ['replace', 178, 179, 163, 164], ['replace', 179, 180, 164, 165], ['replace', 180, 181, 165, 166], ['replace', 181, 182, 166, 167], ['replace', 182, 183, 167, 168], ['replace', 183, 184, 168, 169], ['equal', 184, 185, 169, 170], ['replace', 185, 186, 170, 171], ['replace', 186, 187, 171, 172], ['replace', 187, 188, 172, 173], ['replace', 188, 189, 173, 174], ['replace', 189, 190, 174, 175], ['replace', 190, 191, 175, 176], ['replace', 191, 192, 176, 177], ['replace', 192, 193, 177, 178], ['replace', 193, 194, 178, 179], ['replace', 194, 195, 179, 180], ['equal', 195, 196, 180, 181], ['replace', 196, 197, 181, 182], ['replace', 197, 198, 182, 183], ['replace', 198, 199, 183, 184], ['replace', 199, 200, 184, 185], ['replace', 200, 201, 185, 186], ['replace', 201, 202, 186, 187], ['equal', 202, 203, 187, 188], ['equal', 203, 204, 188, 189], ['insert', 203, 203, 189, 190], ['replace', 204, 205, 190, 191], ['replace', 205, 206, 191, 192], ['replace', 206, 207, 192, 193], ['equal', 207, 208, 193, 194], ['replace', 208, 209, 194, 195], ['replace', 209, 210, 195, 196], ['replace', 210, 211, 196, 197], ['replace', 211, 212, 197, 198], ['replace', 212, 213, 198, 199], ['replace', 213, 214, 199, 200], ['equal', 214, 215, 200, 201], ['insert', 214, 214, 201, 202], ['equal', 215, 216, 202, 203], ['insert', 215, 215, 203, 204], ['replace', 216, 217, 204, 205], ['replace', 217, 218, 205, 206], ['equal', 218, 219, 206, 207], ['insert', 218, 218, 207, 208], ['insert', 218, 218, 208, 209], ['equal', 219, 220, 209, 210], ['insert', 219, 219, 210, 211], ['replace', 220, 221, 211, 212], ['replace', 221, 222, 212, 213], ['replace', 222, 223, 213, 214], ['replace', 223, 224, 214, 215], ['replace', 224, 225, 215, 216], ['replace', 225, 226, 216, 217], ['replace', 226, 227, 217, 218], ['replace', 227, 228, 218, 219], ['equal', 228, 229, 219, 220], ['replace', 229, 230, 220, 221], ['replace', 230, 231, 221, 222], ['replace', 231, 232, 222, 223], ['replace', 232, 233, 223, 224], ['replace', 233, 234, 224, 225], ['replace', 234, 235, 225, 226], ['replace', 235, 236, 226, 227], ['replace', 236, 237, 227, 228], ['replace', 237, 238, 228, 229], ['replace', 238, 239, 229, 230], ['replace', 239, 240, 230, 231], ['replace', 240, 241, 231, 232], ['replace', 241, 242, 232, 233], ['replace', 242, 243, 233, 234], ['replace', 243, 244, 234, 235], ['replace', 244, 245, 235, 236], ['replace', 245, 246, 236, 237], ['replace', 246, 247, 237, 238], ['replace', 247, 248, 238, 239], ['replace', 248, 249, 239, 240], ['equal', 249, 250, 240, 241], ['replace', 250, 251, 241, 242], ['replace', 251, 252, 242, 243], ['replace', 252, 253, 243, 244], ['replace', 253, 254, 244, 245], ['replace', 254, 255, 245, 246], ['equal', 255, 256, 246, 247], ['delete', 256, 257, 246, 246], ['delete', 257, 258, 246, 246], ['replace', 258, 259, 247, 248], ['replace', 259, 260, 248, 249], ['equal', 260, 261, 249, 250], ['delete', 261, 262, 249, 249], ['equal', 262, 263, 250, 251], ['replace', 263, 264, 251, 252], ['replace', 264, 265, 252, 253], ['replace', 265, 266, 253, 254], ['equal', 266, 267, 254, 255], ['insert', 266, 266, 255, 256], ['replace', 267, 268, 256, 257], ['replace', 268, 269, 257, 258], ['replace', 269, 270, 258, 259], ['equal', 270, 271, 259, 260], ['replace', 271, 272, 260, 261], ['replace', 272, 273, 261, 262], ['equal', 273, 274, 262, 263], ['insert', 273, 273, 263, 264], ['replace', 274, 275, 264, 265], ['replace', 275, 276, 265, 266], ['equal', 276, 277, 266, 267], ['insert', 276, 276, 267, 268], ['replace', 277, 278, 268, 269], ['replace', 278, 279, 269, 270], ['replace', 279, 280, 270, 271], ['replace', 280, 281, 271, 272], ['equal', 281, 282, 272, 273], ['replace', 282, 283, 273, 274], ['replace', 283, 284, 274, 275], ['equal', 284, 285, 275, 276], ['replace', 285, 286, 276, 277], ['replace', 286, 287, 277, 278], ['replace', 287, 288, 278, 279], ['replace', 288, 289, 279, 280], ['replace', 289, 290, 280, 281], ['equal', 290, 291, 281, 282], ['replace', 291, 292, 282, 283], ['replace', 292, 293, 283, 284], ['replace', 293, 294, 284, 285], ['replace', 294, 295, 285, 286], ['replace', 295, 296, 286, 287], ['replace', 296, 297, 287, 288], ['equal', 297, 298, 288, 289], ['insert', 297, 297, 289, 290], ['insert', 297, 297, 290, 291], ['replace', 298, 299, 291, 292], ['replace', 299, 300, 292, 293], ['equal', 300, 301, 293, 294], ['insert', 300, 300, 294, 295], ['insert', 300, 300, 295, 296], ['replace', 301, 302, 296, 297], ['replace', 302, 303, 297, 298], ['replace', 303, 304, 298, 299], ['replace', 304, 305, 299, 300], ['replace', 305, 306, 300, 301], ['equal', 306, 307, 301, 302], ['equal', 307, 308, 302, 303], ['insert', 307, 307, 303, 304], ['insert', 307, 307, 304, 305], ['insert', 307, 307, 305, 306], ['insert', 307, 307, 306, 307], ['replace', 308, 309, 307, 308], ['equal', 309, 310, 308, 309], ['insert', 309, 309, 309, 310], ['replace', 310, 311, 310, 311], ['equal', 311, 312, 311, 312], ['insert', 311, 311, 312, 313], ['replace', 312, 313, 313, 314], ['replace', 313, 314, 314, 315], ['replace', 314, 315, 315, 316], ['replace', 315, 316, 316, 317], ['equal', 316, 317, 317, 318], ['replace', 317, 318, 318, 319], ['replace', 318, 319, 319, 320], ['replace', 319, 320, 320, 321], ['replace', 320, 321, 321, 322], ['replace', 321, 322, 322, 323], ['equal', 322, 323, 323, 324], ['replace', 323, 324, 324, 325], ['replace', 324, 325, 325, 326], ['replace', 325, 326, 326, 327], ['equal', 326, 327, 327, 328], ['replace', 327, 328, 328, 329], ['replace', 328, 329, 329, 330], ['replace', 329, 330, 330, 331], ['replace', 330, 331, 331, 332], ['replace', 331, 332, 332, 333], ['replace', 332, 333, 333, 334], ['replace', 333, 334, 334, 335], ['replace', 334, 335, 335, 336], ['replace', 335, 336, 336, 337], ['replace', 336, 337, 337, 338], ['equal', 337, 338, 338, 339], ['replace', 338, 339, 339, 340], ['replace', 339, 340, 340, 341], ['replace', 340, 341, 341, 342], ['replace', 341, 342, 342, 343], ['replace', 342, 343, 343, 344], ['replace', 343, 344, 344, 345], ['replace', 344, 345, 345, 346], ['replace', 345, 346, 346, 347], ['replace', 346, 347, 347, 348], ['replace', 347, 348, 348, 349], ['replace', 348, 349, 349, 350], ['equal', 349, 350, 350, 351], ['replace', 350, 351, 351, 352], ['equal', 351, 352, 352, 353], ['insert', 351, 351, 353, 354], ['replace', 352, 353, 354, 355], ['replace', 353, 354, 355, 356], ['replace', 354, 355, 356, 357], ['replace', 355, 356, 357, 358], ['replace', 356, 357, 358, 359], ['replace', 357, 358, 359, 360], ['replace', 358, 359, 360, 361], ['replace', 359, 360, 361, 362], ['equal', 360, 361, 362, 363], ['replace', 361, 362, 363, 364], ['replace', 362, 363, 364, 365], ['replace', 363, 364, 365, 366], ['replace', 364, 365, 366, 367], ['replace', 365, 366, 367, 368], ['equal', 366, 367, 368, 369], ['insert', 366, 366, 369, 370], ['equal', 367, 368, 370, 371], ['insert', 367, 367, 371, 372], ['replace', 368, 369, 372, 373], ['replace', 369, 370, 373, 374], ['replace', 370, 371, 374, 375], ['replace', 371, 372, 375, 376], ['replace', 372, 373, 376, 377], ['replace', 373, 374, 377, 378], ['equal', 374, 375, 378, 379], ['replace', 375, 376, 379, 380], ['replace', 376, 377, 380, 381], ['replace', 377, 378, 381, 382], ['replace', 378, 379, 382, 383], ['replace', 379, 380, 383, 384], ['replace', 380, 381, 384, 385], ['replace', 381, 382, 385, 386], ['equal', 382, 383, 386, 387], ['delete', 383, 384, 386, 386], ['replace', 384, 385, 387, 388], ['replace', 385, 386, 388, 389], ['equal', 386, 387, 389, 390], ['replace', 387, 388, 390, 391], ['replace', 388, 389, 391, 392], ['replace', 389, 390, 392, 393], ['replace', 390, 391, 393, 394], ['replace', 391, 392, 394, 395], ['replace', 392, 393, 395, 396], ['replace', 393, 394, 396, 397], ['replace', 394, 395, 397, 398], ['replace', 395, 396, 398, 399], ['replace', 396, 397, 399, 400], ['equal', 397, 398, 400, 401], ['delete', 398, 399, 400, 400], ['replace', 399, 400, 401, 402], ['equal', 400, 401, 402, 403], ['replace', 401, 402, 403, 404], ['replace', 402, 403, 404, 405], ['replace', 403, 404, 405, 406], ['replace', 404, 405, 406, 407], ['replace', 405, 406, 407, 408], ['replace', 406, 407, 408, 409], ['replace', 407, 408, 409, 410], ['replace', 408, 409, 410, 411], ['replace', 409, 410, 411, 412], ['replace', 410, 411, 412, 413], ['replace', 411, 412, 413, 414], ['replace', 412, 413, 414, 415], ['equal', 413, 414, 415, 416], ['insert', 413, 413, 416, 417], ['replace', 414, 415, 417, 418], ['replace', 415, 416, 418, 419], ['equal', 416, 417, 419, 420], ['insert', 416, 416, 420, 421], ['insert', 416, 416, 421, 422], ['replace', 417, 418, 422, 423], ['replace', 418, 419, 423, 424], ['replace', 419, 420, 424, 425], ['equal', 420, 421, 425, 426], ['insert', 420, 420, 426, 427], ['insert', 420, 420, 427, 428], ['replace', 421, 422, 428, 429], ['replace', 422, 423, 429, 430], ['replace', 423, 424, 430, 431], ['replace', 424, 425, 431, 432], ['equal', 425, 426, 432, 433], ['replace', 426, 427, 433, 434], ['replace', 427, 428, 434, 435], ['replace', 428, 429, 435, 436], ['replace', 429, 430, 436, 437], ['replace', 430, 431, 437, 438], ['replace', 431, 432, 438, 439], ['equal', 432, 433, 439, 440], ['replace', 433, 434, 440, 441], ['replace', 434, 435, 441, 442], ['replace', 435, 436, 442, 443], ['replace', 436, 437, 443, 444], ['replace', 437, 438, 444, 445], ['replace', 438, 439, 445, 446], ['replace', 439, 440, 446, 447], ['equal', 440, 441, 447, 448], ['insert', 440, 440, 448, 449], ['replace', 441, 442, 449, 450], ['replace', 442, 443, 450, 451], ['replace', 443, 444, 451, 452], ['replace', 444, 445, 452, 453], ['equal', 445, 446, 453, 454], ['insert', 445, 445, 454, 455], ['replace', 446, 447, 455, 456], ['replace', 447, 448, 456, 457], ['replace', 448, 449, 457, 458], ['equal', 449, 450, 458, 459], ['replace', 450, 451, 459, 460], ['replace', 451, 452, 460, 461], ['replace', 452, 453, 461, 462], ['replace', 453, 454, 462, 463], ['replace', 454, 455, 463, 464], ['replace', 455, 456, 464, 465], ['equal', 456, 457, 465, 466], ['replace', 457, 458, 466, 467], ['replace', 458, 459, 467, 468], ['replace', 459, 460, 468, 469], ['replace', 460, 461, 469, 470], ['equal', 461, 462, 470, 471], ['replace', 462, 463, 471, 472], ['equal', 463, 464, 472, 473], ['delete', 464, 465, 472, 472], ['replace', 465, 466, 473, 474], ['replace', 466, 467, 474, 475], ['replace', 467, 468, 475, 476], ['replace', 468, 469, 476, 477], ['replace', 469, 470, 477, 478], ['replace', 470, 471, 478, 479], ['equal', 471, 472, 479, 480], ['equal', 472, 473, 480, 481], ['equal', 473, 474, 481, 482], ['replace', 474, 475, 482, 483], ['replace', 475, 476, 483, 484], ['replace', 476, 477, 484, 485], ['equal', 477, 478, 485, 486], ['insert', 477, 477, 486, 487], ['replace', 478, 479, 487, 488], ['replace', 479, 480, 488, 489], ['replace', 480, 481, 489, 490], ['replace', 481, 482, 490, 491], ['replace', 482, 483, 491, 492], ['replace', 483, 484, 492, 493], ['replace', 484, 485, 493, 494], ['replace', 485, 486, 494, 495], ['replace', 486, 487, 495, 496], ['replace', 487, 488, 496, 497], ['replace', 488, 489, 497, 498], ['replace', 489, 490, 498, 499], ['replace', 490, 491, 499, 500], ['replace', 491, 492, 500, 501], ['replace', 492, 493, 501, 502], ['equal', 493, 494, 502, 503], ['insert', 493, 493, 503, 504], ['replace', 494, 495, 504, 505], ['replace', 495, 496, 505, 506], ['replace', 496, 497, 506, 507], ['replace', 497, 498, 507, 508], ['replace', 498, 499, 508, 509], ['replace', 499, 500, 509, 510], ['replace', 500, 501, 510, 511], ['replace', 501, 502, 511, 512], ['replace', 502, 503, 512, 513], ['replace', 503, 504, 513, 514], ['replace', 504, 505, 514, 515], ['replace', 505, 506, 515, 516], ['replace', 506, 507, 516, 517], ['replace', 507, 508, 517, 518], ['replace', 508, 509, 518, 519], ['replace', 509, 510, 519, 520], ['replace', 510, 511, 520, 521], ['replace', 511, 512, 521, 522], ['replace', 512, 513, 522, 523], ['replace', 513, 514, 523, 524], ['replace', 514, 515, 524, 525], ['equal', 515, 516, 525, 526], ['replace', 516, 517, 526, 527], ['replace', 517, 518, 527, 528], ['replace', 518, 519, 528, 529], ['replace', 519, 520, 529, 530], ['replace', 520, 521, 530, 531], ['replace', 521, 522, 531, 532], ['replace', 522, 523, 532, 533], ['replace', 523, 524, 533, 534], ['equal', 524, 525, 534, 535], ['replace', 525, 526, 535, 536], ['replace', 526, 527, 536, 537], ['replace', 527, 528, 537, 538], ['replace', 528, 529, 538, 539], ['equal', 529, 530, 539, 540], ['replace', 530, 531, 540, 541], ['equal', 531, 532, 541, 542], ['replace', 532, 533, 542, 543], ['replace', 533, 534, 543, 544], ['replace', 534, 535, 544, 545], ['replace', 535, 536, 545, 546], ['equal', 536, 537, 546, 547], ['replace', 537, 538, 547, 548], ['replace', 538, 539, 548, 549], ['replace', 539, 540, 549, 550], ['replace', 540, 541, 550, 551], ['replace', 541, 542, 551, 552], ['replace', 542, 543, 552, 553], ['replace', 543, 544, 553, 554], ['replace', 544, 545, 554, 555], ['replace', 545, 546, 555, 556], ['replace', 546, 547, 556, 557], ['replace', 547, 548, 557, 558], ['replace', 548, 549, 558, 559], ['replace', 549, 550, 559, 560], ['replace', 550, 551, 560, 561], ['replace', 551, 552, 561, 562], ['equal', 552, 553, 562, 563], ['replace', 553, 554, 563, 564], ['equal', 554, 555, 564, 565], ['replace', 555, 556, 565, 566], ['replace', 556, 557, 566, 567], ['replace', 557, 558, 567, 568], ['replace', 558, 559, 568, 569], ['replace', 559, 560, 569, 570], ['replace', 560, 561, 570, 571], ['replace', 561, 562, 571, 572], ['replace', 562, 563, 572, 573], ['equal', 563, 564, 573, 574], ['insert', 563, 563, 574, 575], ['replace', 564, 565, 575, 576], ['replace', 565, 566, 576, 577], ['replace', 566, 567, 577, 578], ['replace', 567, 568, 578, 579], ['replace', 568, 569, 579, 580], ['equal', 569, 570, 580, 581], ['insert', 569, 569, 581, 582], ['insert', 569, 569, 582, 583], ['insert', 569, 569, 583, 584], ['insert', 569, 569, 584, 585], ['insert', 569, 569, 585, 586], ['replace', 570, 571, 586, 587], ['replace', 571, 572, 587, 588], ['replace', 572, 573, 588, 589], ['replace', 573, 574, 589, 590], ['replace', 574, 575, 590, 591], ['replace', 575, 576, 591, 592], ['replace', 576, 577, 592, 593], ['replace', 577, 578, 593, 594], ['replace', 578, 579, 594, 595], ['replace', 579, 580, 595, 596], ['equal', 580, 581, 596, 597], ['replace', 581, 582, 597, 598], ['replace', 582, 583, 598, 599], ['replace', 583, 584, 599, 600], ['replace', 584, 585, 600, 601], ['replace', 585, 586, 601, 602], ['replace', 586, 587, 602, 603], ['replace', 587, 588, 603, 604], ['replace', 588, 589, 604, 605], ['replace', 589, 590, 605, 606], ['replace', 590, 591, 606, 607], ['replace', 591, 592, 607, 608], ['replace', 592, 593, 608, 609], ['replace', 593, 594, 609, 610], ['replace', 594, 595, 610, 611], ['replace', 595, 596, 611, 612], ['replace', 596, 597, 612, 613], ['replace', 597, 598, 613, 614], ['equal', 598, 599, 614, 615], ['insert', 598, 598, 615, 616], ['insert', 598, 598, 616, 617], ['replace', 599, 600, 617, 618], ['replace', 600, 601, 618, 619], ['equal', 601, 602, 619, 620], ['replace', 602, 603, 620, 621], ['replace', 603, 604, 621, 622], ['replace', 604, 605, 622, 623], ['replace', 605, 606, 623, 624], ['replace', 606, 607, 624, 625], ['replace', 607, 608, 625, 626], ['equal', 608, 609, 626, 627], ['insert', 608, 608, 627, 628], ['insert', 608, 608, 628, 629], ['replace', 609, 610, 629, 630], ['equal', 610, 611, 630, 631], ['replace', 611, 612, 631, 632], ['replace', 612, 613, 632, 633], ['replace', 613, 614, 633, 634], ['replace', 614, 615, 634, 635], ['replace', 615, 616, 635, 636], ['replace', 616, 617, 636, 637], ['equal', 617, 618, 637, 638], ['replace', 618, 619, 638, 639], ['replace', 619, 620, 639, 640], ['replace', 620, 621, 640, 641], ['replace', 621, 622, 641, 642], ['replace', 622, 623, 642, 643], ['replace', 623, 624, 643, 644], ['replace', 624, 625, 644, 645], ['replace', 625, 626, 645, 646], ['replace', 626, 627, 646, 647], ['equal', 627, 628, 647, 648], ['insert', 627, 627, 648, 649], ['replace', 628, 629, 649, 650], ['replace', 629, 630, 650, 651], ['replace', 630, 631, 651, 652], ['replace', 631, 632, 652, 653], ['replace', 632, 633, 653, 654], ['replace', 633, 634, 654, 655], ['replace', 634, 635, 655, 656], ['replace', 635, 636, 656, 657], ['replace', 636, 637, 657, 658], ['replace', 637, 638, 658, 659], ['replace', 638, 639, 659, 660], ['replace', 639, 640, 660, 661], ['replace', 640, 641, 661, 662], ['replace', 641, 642, 662, 663], ['replace', 642, 643, 663, 664], ['replace', 643, 644, 664, 665], ['equal', 644, 645, 665, 666], ['replace', 645, 646, 666, 667], ['replace', 646, 647, 667, 668], ['replace', 647, 648, 668, 669], ['replace', 648, 649, 669, 670], ['equal', 649, 650, 670, 671], ['replace', 650, 651, 671, 672], ['replace', 651, 652, 672, 673], ['replace', 652, 653, 673, 674], ['replace', 653, 654, 674, 675], ['replace', 654, 655, 675, 676], ['replace', 655, 656, 676, 677], ['equal', 656, 657, 677, 678], ['insert', 656, 656, 678, 679], ['insert', 656, 656, 679, 680], ['insert', 656, 656, 680, 681], ['replace', 657, 658, 681, 682], ['equal', 658, 659, 682, 683], ['replace', 659, 660, 683, 684], ['equal', 660, 661, 684, 685], ['insert', 660, 660, 685, 686], ['replace', 661, 662, 686, 687], ['replace', 662, 663, 687, 688], ['replace', 663, 664, 688, 689], ['replace', 664, 665, 689, 690], ['replace', 665, 666, 690, 691], ['equal', 666, 667, 691, 692], ['equal', 667, 668, 692, 693], ['replace', 668, 669, 693, 694], ['replace', 669, 670, 694, 695], ['replace', 670, 671, 695, 696], ['replace', 671, 672, 696, 697], ['replace', 672, 673, 697, 698], ['replace', 673, 674, 698, 699], ['replace', 674, 675, 699, 700], ['replace', 675, 676, 700, 701], ['replace', 676, 677, 701, 702], ['replace', 677, 678, 702, 703], ['replace', 678, 679, 703, 704], ['replace', 679, 680, 704, 705], ['replace', 680, 681, 705, 706], ['replace', 681, 682, 706, 707], ['replace', 682, 683, 707, 708], ['replace', 683, 684, 708, 709], ['replace', 684, 685, 709, 710], ['replace', 685, 686, 710, 711], ['replace', 686, 687, 711, 712], ['replace', 687, 688, 712, 713], ['replace', 688, 689, 713, 714], ['replace', 689, 690, 714, 715], ['replace', 690, 691, 715, 716], ['equal', 691, 692, 716, 717], ['replace', 692, 693, 717, 718], ['replace', 693, 694, 718, 719], ['replace', 694, 695, 719, 720], ['replace', 695, 696, 720, 721], ['replace', 696, 697, 721, 722], ['replace', 697, 698, 722, 723], ['replace', 698, 699, 723, 724], ['equal', 699, 700, 724, 725], ['delete', 700, 701, 724, 724], ['equal', 701, 702, 725, 726], ['replace', 702, 703, 726, 727], ['replace', 703, 704, 727, 728], ['replace', 704, 705, 728, 729], ['replace', 705, 706, 729, 730], ['replace', 706, 707, 730, 731], ['equal', 707, 708, 731, 732], ['replace', 708, 709, 732, 733], ['equal', 709, 710, 733, 734], ['delete', 710, 711, 733, 733], ['replace', 711, 712, 734, 735], ['replace', 712, 713, 735, 736], ['replace', 713, 714, 736, 737], ['equal', 714, 715, 737, 738], ['delete', 715, 716, 737, 737], ['delete', 716, 717, 737, 737], ['delete', 717, 718, 737, 737], ['replace', 718, 719, 738, 739], ['equal', 719, 720, 739, 740], ['delete', 720, 721, 739, 739], ['replace', 721, 722, 740, 741], ['replace', 722, 723, 741, 742], ['replace', 723, 724, 742, 743], ['replace', 724, 725, 743, 744], ['replace', 725, 726, 744, 745], ['replace', 726, 727, 745, 746], ['replace', 727, 728, 746, 747], ['replace', 728, 729, 747, 748], ['equal', 729, 730, 748, 749], ['replace', 730, 731, 749, 750], ['equal', 731, 732, 750, 751], ['replace', 732, 733, 751, 752], ['replace', 733, 734, 752, 753], ['replace', 734, 735, 753, 754], ['equal', 735, 736, 754, 755], ['replace', 736, 737, 755, 756], ['replace', 737, 738, 756, 757], ['replace', 738, 739, 757, 758], ['replace', 739, 740, 758, 759], ['replace', 740, 741, 759, 760], ['replace', 741, 742, 760, 761], ['replace', 742, 743, 761, 762], ['replace', 743, 744, 762, 763], ['equal', 744, 745, 763, 764], ['replace', 745, 746, 764, 765], ['replace', 746, 747, 765, 766], ['replace', 747, 748, 766, 767], ['replace', 748, 749, 767, 768], ['replace', 749, 750, 768, 769], ['replace', 750, 751, 769, 770], ['replace', 751, 752, 770, 771], ['replace', 752, 753, 771, 772], ['replace', 753, 754, 772, 773], ['replace', 754, 755, 773, 774], ['replace', 755, 756, 774, 775], ['replace', 756, 757, 775, 776], ['replace', 757, 758, 776, 777], ['replace', 758, 759, 777, 778], ['replace', 759, 760, 778, 779], ['equal', 760, 761, 779, 780], ['replace', 761, 762, 780, 781], ['equal', 762, 763, 781, 782], ['replace', 763, 764, 782, 783], ['replace', 764, 765, 783, 784], ['equal', 765, 766, 784, 785], ['replace', 766, 767, 785, 786], ['equal', 767, 768, 786, 787], ['replace', 768, 769, 787, 788], ['replace', 769, 770, 788, 789], ['replace', 770, 771, 789, 790], ['equal', 771, 772, 790, 791], ['insert', 771, 771, 791, 792], ['replace', 772, 773, 792, 793], ['replace', 773, 774, 793, 794], ['replace', 774, 775, 794, 795], ['replace', 775, 776, 795, 796], ['replace', 776, 777, 796, 797], ['replace', 777, 778, 797, 798], ['replace', 778, 779, 798, 799], ['replace', 779, 780, 799, 800], ['equal', 780, 781, 800, 801], ['replace', 781, 782, 801, 802], ['replace', 782, 783, 802, 803], ['replace', 783, 784, 803, 804], ['replace', 784, 785, 804, 805], ['replace', 785, 786, 805, 806], ['equal', 786, 787, 806, 807], ['replace', 787, 788, 807, 808], ['equal', 788, 789, 808, 809], ['replace', 789, 790, 809, 810], ['replace', 790, 791, 810, 811], ['replace', 791, 792, 811, 812], ['replace', 792, 793, 812, 813], ['replace', 793, 794, 813, 814], ['replace', 794, 795, 814, 815], ['replace', 795, 796, 815, 816], ['replace', 796, 797, 816, 817], ['equal', 797, 798, 817, 818], ['insert', 797, 797, 818, 819], ['insert', 797, 797, 819, 820], ['insert', 797, 797, 820, 821], ['replace', 798, 799, 821, 822], ['replace', 799, 800, 822, 823], ['equal', 800, 801, 823, 824], ['replace', 801, 802, 824, 825], ['replace', 802, 803, 825, 826], ['replace', 803, 804, 826, 827], ['replace', 804, 805, 827, 828], ['replace', 805, 806, 828, 829], ['replace', 806, 807, 829, 830], ['equal', 807, 808, 830, 831], ['replace', 808, 809, 831, 832], ['replace', 809, 810, 832, 833], ['replace', 810, 811, 833, 834], ['replace', 811, 812, 834, 835], ['replace', 812, 813, 835, 836], ['replace', 813, 814, 836, 837], ['replace', 814, 815, 837, 838], ['equal', 815, 816, 838, 839], ['replace', 816, 817, 839, 840], ['replace', 817, 818, 840, 841], ['replace', 818, 819, 841, 842], ['replace', 819, 820, 842, 843], ['replace', 820, 821, 843, 844], ['replace', 821, 822, 844, 845], ['replace', 822, 823, 845, 846], ['equal', 823, 824, 846, 847], ['replace', 824, 825, 847, 848], ['replace', 825, 826, 848, 849], ['replace', 826, 827, 849, 850], ['replace', 827, 828, 850, 851], ['replace', 828, 829, 851, 852], ['replace', 829, 830, 852, 853], ['equal', 830, 831, 853, 854], ['replace', 831, 832, 854, 855], ['replace', 832, 833, 855, 856], ['replace', 833, 834, 856, 857], ['replace', 834, 835, 857, 858], ['equal', 835, 836, 858, 859], ['replace', 836, 837, 859, 860], ['replace', 837, 838, 860, 861], ['equal', 838, 839, 861, 862], ['replace', 839, 840, 862, 863], ['replace', 840, 841, 863, 864], ['replace', 841, 842, 864, 865], ['equal', 842, 843, 865, 866], ['equal', 843, 844, 866, 867], ['delete', 844, 845, 866, 866], ['delete', 845, 846, 866, 866], ['replace', 846, 847, 867, 868], ['replace', 847, 848, 868, 869], ['replace', 848, 849, 869, 870], ['replace', 849, 850, 870, 871], ['equal', 850, 851, 871, 872], ['replace', 851, 852, 872, 873], ['replace', 852, 853, 873, 874], ['replace', 853, 854, 874, 875], ['replace', 854, 855, 875, 876], ['replace', 855, 856, 876, 877], ['replace', 856, 857, 877, 878], ['replace', 857, 858, 878, 879], ['replace', 858, 859, 879, 880], ['replace', 859, 860, 880, 881], ['replace', 860, 861, 881, 882], ['replace', 861, 862, 882, 883], ['replace', 862, 863, 883, 884], ['replace', 863, 864, 884, 885], ['replace', 864, 865, 885, 886], ['equal', 865, 866, 886, 887], ['delete', 866, 867, 886, 886], ['replace', 867, 868, 887, 888], ['replace', 868, 869, 888, 889], ['equal', 869, 870, 889, 890], ['delete', 870, 871, 889, 889], ['delete', 871, 872, 889, 889], ['equal', 872, 873, 890, 891], ['replace', 873, 874, 891, 892], ['equal', 874, 875, 892, 893], ['replace', 875, 876, 893, 894], ['replace', 876, 877, 894, 895], ['equal', 877, 878, 895, 896], ['delete', 878, 879, 895, 895], ['equal', 879, 880, 896, 897], ['delete', 880, 881, 896, 896], ['delete', 881, 882, 896, 896], ['delete', 882, 883, 896, 896], ['replace', 883, 884, 897, 898], ['equal', 884, 885, 898, 899], ['delete', 885, 886, 898, 898], ['delete', 886, 887, 898, 898], ['delete', 887, 888, 898, 898], ['equal', 888, 889, 899, 900], ['replace', 889, 890, 900, 901], ['replace', 890, 891, 901, 902], ['replace', 891, 892, 902, 903], ['replace', 892, 893, 903, 904], ['equal', 893, 894, 904, 905], ['delete', 894, 895, 904, 904], ['replace', 895, 896, 905, 906], ['equal', 896, 897, 906, 907], ['replace', 897, 898, 907, 908], ['replace', 898, 899, 908, 909], ['replace', 899, 900, 909, 910], ['replace', 900, 901, 910, 911], ['replace', 901, 902, 911, 912], ['equal', 902, 903, 912, 913], ['equal', 903, 904, 913, 914], ['replace', 904, 905, 914, 915], ['replace', 905, 906, 915, 916], ['replace', 906, 907, 916, 917], ['replace', 907, 908, 917, 918], ['replace', 908, 909, 918, 919], ['replace', 909, 910, 919, 920], ['replace', 910, 911, 920, 921], ['replace', 911, 912, 921, 922], ['replace', 912, 913, 922, 923], ['replace', 913, 914, 923, 924], ['equal', 914, 915, 924, 925], ['equal', 915, 916, 925, 926], ['delete', 916, 917, 925, 925], ['replace', 917, 918, 926, 927], ['replace', 918, 919, 927, 928], ['replace', 919, 920, 928, 929], ['replace', 920, 921, 929, 930], ['replace', 921, 922, 930, 931], ['replace', 922, 923, 931, 932], ['replace', 923, 924, 932, 933], ['replace', 924, 925, 933, 934], ['replace', 925, 926, 934, 935], ['equal', 926, 927, 935, 936], ['replace', 927, 928, 936, 937], ['replace', 928, 929, 937, 938], ['replace', 929, 930, 938, 939], ['replace', 930, 931, 939, 940], ['replace', 931, 932, 940, 941], ['equal', 932, 933, 941, 942], ['equal', 933, 934, 942, 943], ['delete', 934, 935, 942, 942], ['delete', 935, 936, 942, 942], ['delete', 936, 937, 942, 942], ['delete', 937, 938, 942, 942], ['delete', 938, 939, 942, 942], ['replace', 939, 940, 943, 944], ['replace', 940, 941, 944, 945], ['replace', 941, 942, 945, 946], ['equal', 942, 943, 946, 947], ['delete', 943, 944, 946, 946], ['delete', 944, 945, 946, 946], ['equal', 945, 946, 947, 948], ['replace', 946, 947, 948, 949], ['replace', 947, 948, 949, 950], ['replace', 948, 949, 950, 951], ['replace', 949, 950, 951, 952], ['replace', 950, 951, 952, 953], ['replace', 951, 952, 953, 954], ['replace', 952, 953, 954, 955], ['replace', 953, 954, 955, 956], ['replace', 954, 955, 956, 957], ['equal', 955, 956, 957, 958], ['replace', 956, 957, 958, 959], ['replace', 957, 958, 959, 960], ['equal', 958, 959, 960, 961], ['replace', 959, 960, 961, 962], ['replace', 960, 961, 962, 963], ['replace', 961, 962, 963, 964], ['replace', 962, 963, 964, 965], ['replace', 963, 964, 965, 966], ['replace', 964, 965, 966, 967], ['equal', 965, 966, 967, 968], ['equal', 966, 967, 968, 969], ['insert', 966, 966, 969, 970], ['replace', 967, 968, 970, 971], ['replace', 968, 969, 971, 972], ['replace', 969, 970, 972, 973], ['replace', 970, 971, 973, 974], ['replace', 971, 972, 974, 975], ['replace', 972, 973, 975, 976], ['replace', 973, 974, 976, 977], ['replace', 974, 975, 977, 978], ['replace', 975, 976, 978, 979], ['equal', 976, 977, 979, 980], ['replace', 977, 978, 980, 981], ['replace', 978, 979, 981, 982], ['replace', 979, 980, 982, 983], ['equal', 980, 981, 983, 984], ['insert', 980, 980, 984, 985], ['replace', 981, 982, 985, 986], ['replace', 982, 983, 986, 987], ['replace', 983, 984, 987, 988], ['replace', 984, 985, 988, 989], ['equal', 985, 986, 989, 990], ['replace', 986, 987, 990, 991], ['equal', 987, 988, 991, 992], ['delete', 988, 989, 991, 991], ['delete', 989, 990, 991, 991], ['delete', 990, 991, 991, 991], ['delete', 991, 992, 991, 991], ['replace', 992, 993, 992, 993], ['replace', 993, 994, 993, 994], ['replace', 994, 995, 994, 995], ['replace', 995, 996, 995, 996], ['replace', 996, 997, 996, 997], ['replace', 997, 998, 997, 998], ['replace', 998, 999, 998, 999], ['replace', 999, 1000, 999, 1000]])
